@@ -28,9 +28,8 @@
 
 
 import sys
-import os
 
-sys.path.insert(0, os.path.dirname(os.path.realpath(__file__) + '/../'))
+sys.path.insert(0, '/usr/local/monitoring')
 
 from monitoring_utils.Notification.Telegram.HostNotification import HostNotification
 
