@@ -27,9 +27,8 @@
 #  and also my other projects <https://github.com/f-froehlich>
 
 import sys
-import os
 
-sys.path.insert(0, os.path.dirname(os.path.realpath(__file__) + '/../'))
+sys.path.insert(0, '/usr/local/monitoring')
 
 from monitoring_utils.Notification.Telegram.ServiceNotification import ServiceNotification
 
